@@ -1,5 +1,21 @@
-#ifndef ANALYSIS_COMMON_R_BSTS_SRC_STATE_SPACE_LOGIT_MODEL_MANAGER_H_
-#define ANALYSIS_COMMON_R_BSTS_SRC_STATE_SPACE_LOGIT_MODEL_MANAGER_H_
+// Copyright 2018 Google Inc. All Rights Reserved.
+//
+// This library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Lesser General Public
+// License as published by the Free Software Foundation; either
+// version 2.1 of the License, or (at your option) any later version.
+//
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+// Lesser General Public License for more details.
+//
+// You should have received a copy of the GNU Lesser General Public
+// License along with this library; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+
+#ifndef BSTS_SRC_STATE_SPACE_LOGIT_MODEL_MANAGER_H_
+#define BSTS_SRC_STATE_SPACE_LOGIT_MODEL_MANAGER_H_
 
 #include "model_manager.h"
 #include "LinAlg/Matrix.hpp"
@@ -59,4 +75,4 @@ class StateSpaceLogitModelManager
 }  // namespace bsts
 }  // namespace BOOM
 
-#endif  // ANALYSIS_COMMON_R_BSTS_SRC_STATE_SPACE_LOGIT_MODEL_MANAGER_H_
+#endif  // BSTS_SRC_STATE_SPACE_LOGIT_MODEL_MANAGER_H_
